==> kubernetes-model-flowcontrol-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/LimitedPriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitedPriorityLevelConfigurationFluent<A extends LimitedPriorityLevelConfigurationFluent<A>> extends BaseFluent<A>{
  public LimitedPriorityLevelConfigurationFluent() {
  }
  public LimitedPriorityLevelConfigurationFluent(LimitedPriorityLevelConfiguration instance) {
    instance = (instance != null ? instance : new LimitedPriorityLevelConfiguration());

    if (instance != null) {
      this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares());
      this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent());
      this.withLendablePercent(instance.getLendablePercent());
      this.withLimitResponse(instance.getLimitResponse());
      this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares());
      this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent());
      this.withLendablePercent(instance.getLendablePercent());
      this.withLimitResponse(instance.getLimitResponse());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer assuredConcurrencyShares;
  private Integer borrowingLimitPercent;
  private Integer lendablePercent;
  private LimitResponseBuilder limitResponse;
  private Map<String,Object> additionalProperties;
  public Integer getAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares;
  }
  public A withAssuredConcurrencyShares(Integer assuredConcurrencyShares) {
    this.assuredConcurrencyShares=assuredConcurrencyShares; return (A) this;
  }
  public boolean hasAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares != null;
  }
  public Integer getBorrowingLimitPercent() {
    return this.borrowingLimitPercent;
  }
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent) {
    this.borrowingLimitPercent=borrowingLimitPercent; return (A) this;
  }
  public boolean hasBorrowingLimitPercent() {
    return this.borrowingLimitPercent != null;
  }
  public Integer getLendablePercent() {
    return this.lendablePercent;
  }
  public A withLendablePercent(Integer lendablePercent) {
    this.lendablePercent=lendablePercent; return (A) this;
  }
  public boolean hasLendablePercent() {
    return this.lendablePercent != null;
  }
  public LimitResponse buildLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public A withLimitResponse(LimitResponse limitResponse) {
    _visitables.get("limitResponse").remove(this.limitResponse);
    if (limitResponse!=null){ this.limitResponse= new LimitResponseBuilder(limitResponse); _visitables.get("limitResponse").add(this.limitResponse);} else { this.limitResponse = null; _visitables.get("limitResponse").remove(this.limitResponse); } return (A) this;
  }
  public boolean hasLimitResponse() {
    return this.limitResponse != null;
  }
  public LimitResponseNested<A> withNewLimitResponse() {
    return new LimitResponseNested(null);
  }
  public LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item) {
    return new LimitResponseNested(item);
  }
  public LimitResponseNested<A> editLimitResponse() {
    return withNewLimitResponseLike(java.util.Optional.ofNullable(buildLimitResponse()).orElse(null));
  }
  public LimitResponseNested<A> editOrNewLimitResponse() {
    return withNewLimitResponseLike(java.util.Optional.ofNullable(buildLimitResponse()).orElse(new LimitResponseBuilder().build()));
  }
  public LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item) {
    return withNewLimitResponseLike(java.util.Optional.ofNullable(buildLimitResponse()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LimitedPriorityLevelConfigurationFluent that = (LimitedPriorityLevelConfigurationFluent) o;
    if (!java.util.Objects.equals(assuredConcurrencyShares, that.assuredConcurrencyShares)) return false;

    if (!java.util.Objects.equals(borrowingLimitPercent, that.borrowingLimitPercent)) return false;

    if (!java.util.Objects.equals(lendablePercent, that.lendablePercent)) return false;

    if (!java.util.Objects.equals(limitResponse, that.limitResponse)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(assuredConcurrencyShares,  borrowingLimitPercent,  lendablePercent,  limitResponse,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (assuredConcurrencyShares != null) { sb.append("assuredConcurrencyShares:"); sb.append(assuredConcurrencyShares + ","); }
    if (borrowingLimitPercent != null) { sb.append("borrowingLimitPercent:"); sb.append(borrowingLimitPercent + ","); }
    if (lendablePercent != null) { sb.append("lendablePercent:"); sb.append(lendablePercent + ","); }
    if (limitResponse != null) { sb.append("limitResponse:"); sb.append(limitResponse + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class LimitResponseNested<N> extends LimitResponseFluent<LimitResponseNested<N>> implements Nested<N>{
    LimitResponseNested(LimitResponse item) {
      this.builder = new LimitResponseBuilder(this, item);
    }
    LimitResponseBuilder builder;
    public N and() {
      return (N) LimitedPriorityLevelConfigurationFluent.this.withLimitResponse(builder.build());
    }
    public N endLimitResponse() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/LimitedPriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LimitedPriorityLevelConfigurationFluent<A extends LimitedPriorityLevelConfigurationFluent<A>> extends BaseFluent<A>{
  public LimitedPriorityLevelConfigurationFluent() {
  }
  
  public LimitedPriorityLevelConfigurationFluent(LimitedPriorityLevelConfiguration instance) {
    this.copyInstance(instance);
  }
  private Integer assuredConcurrencyShares;
  private Integer borrowingLimitPercent;
  private Integer lendablePercent;
  private LimitResponseBuilder limitResponse;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(LimitedPriorityLevelConfiguration instance) {
    instance = (instance != null ? instance : new LimitedPriorityLevelConfiguration());
  
    if (instance != null) {
        this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares());
        this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent());
        this.withLendablePercent(instance.getLendablePercent());
        this.withLimitResponse(instance.getLimitResponse());
        this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares());
        this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent());
        this.withLendablePercent(instance.getLendablePercent());
        this.withLimitResponse(instance.getLimitResponse());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Integer getAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares;
  }
  
  public A withAssuredConcurrencyShares(Integer assuredConcurrencyShares) {
    this.assuredConcurrencyShares=assuredConcurrencyShares; return (A) this;
  }
  
  public boolean hasAssuredConcurrencyShares() {
    return this.assuredConcurrencyShares != null;
  }
  
  public Integer getBorrowingLimitPercent() {
    return this.borrowingLimitPercent;
  }
  
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent) {
    this.borrowingLimitPercent=borrowingLimitPercent; return (A) this;
  }
  
  public boolean hasBorrowingLimitPercent() {
    return this.borrowingLimitPercent != null;
  }
  
  public Integer getLendablePercent() {
    return this.lendablePercent;
  }
  
  public A withLendablePercent(Integer lendablePercent) {
    this.lendablePercent=lendablePercent; return (A) this;
  }
  
  public boolean hasLendablePercent() {
    return this.lendablePercent != null;
  }
  
  public LimitResponse buildLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  
  public A withLimitResponse(LimitResponse limitResponse) {
    _visitables.get("limitResponse").remove(this.limitResponse);
    if (limitResponse!=null){ this.limitResponse= new LimitResponseBuilder(limitResponse); _visitables.get("limitResponse").add(this.limitResponse);} else { this.limitResponse = null; _visitables.get("limitResponse").remove(this.limitResponse); } return (A) this;
  }
  
  public boolean hasLimitResponse() {
    return this.limitResponse != null;
  }
  
  public LimitResponseNested<A> withNewLimitResponse() {
    return new LimitResponseNested(null);
  }
  
  public LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item) {
    return new LimitResponseNested(item);
  }
  
  public LimitResponseNested<A> editLimitResponse() {
    return withNewLimitResponseLike(java.util.Optional.ofNullable(buildLimitResponse()).orElse(null));
  }
  
  public LimitResponseNested<A> editOrNewLimitResponse() {
    return withNewLimitResponseLike(java.util.Optional.ofNullable(buildLimitResponse()).orElse(new LimitResponseBuilder().build()));
  }
  
  public LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item) {
    return withNewLimitResponseLike(java.util.Optional.ofNullable(buildLimitResponse()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LimitedPriorityLevelConfigurationFluent that = (LimitedPriorityLevelConfigurationFluent) o;
    if (!java.util.Objects.equals(assuredConcurrencyShares, that.assuredConcurrencyShares)) return false;
  
    if (!java.util.Objects.equals(borrowingLimitPercent, that.borrowingLimitPercent)) return false;
  
    if (!java.util.Objects.equals(lendablePercent, that.lendablePercent)) return false;
  
    if (!java.util.Objects.equals(limitResponse, that.limitResponse)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(assuredConcurrencyShares,  borrowingLimitPercent,  lendablePercent,  limitResponse,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (assuredConcurrencyShares != null) { sb.append("assuredConcurrencyShares:"); sb.append(assuredConcurrencyShares + ","); }
    if (borrowingLimitPercent != null) { sb.append("borrowingLimitPercent:"); sb.append(borrowingLimitPercent + ","); }
    if (lendablePercent != null) { sb.append("lendablePercent:"); sb.append(lendablePercent + ","); }
    if (limitResponse != null) { sb.append("limitResponse:"); sb.append(limitResponse + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class LimitResponseNested<N> extends LimitResponseFluent<LimitResponseNested<N>> implements Nested<N>{
    LimitResponseNested(LimitResponse item) {
      this.builder = new LimitResponseBuilder(this, item);
    }
    LimitResponseBuilder builder;
    
    public N and() {
      return (N) LimitedPriorityLevelConfigurationFluent.this.withLimitResponse(builder.build());
    }
    
    public N endLimitResponse() {
      return and();
    }
    
  
  }

}
